@@ -56,8 +56,13 @@ gboolean _ostree_fetcher_mirrored_request_to_membuf (OstreeFetcher *fetcher,
                                                      GPtrArray     *mirrorlist,
                                                      const char    *filename,
                                                      OstreeFetcherRequestFlags flags,
+                                                     const char    *if_none_match,
+                                                     guint64        if_modified_since,
                                                      guint          n_network_retries,
                                                      GBytes         **out_contents,
+                                                     gboolean      *out_not_modified,
+                                                     char         **out_etag,
+                                                     guint64       *out_last_modified,
                                                      guint64        max_size,
                                                      GCancellable   *cancellable,
                                                      GError         **error);
@@ -65,8 +70,13 @@ gboolean _ostree_fetcher_mirrored_request_to_membuf (OstreeFetcher *fetcher,
 gboolean _ostree_fetcher_request_uri_to_membuf (OstreeFetcher *fetcher,
                                                 OstreeFetcherURI *uri,
                                                 OstreeFetcherRequestFlags flags,
+                                                const char    *if_none_match,
+                                                guint64        if_modified_since,
                                                 guint          n_network_retries,
                                                 GBytes         **out_contents,
+                                                gboolean      *out_not_modified,
+                                                char         **out_etag,
+                                                guint64       *out_last_modified,
                                                 guint64        max_size,
                                                 GCancellable   *cancellable,
                                                 GError         **error);
