@@ -123,6 +123,8 @@ void _ostree_fetcher_request_to_tmpfile (OstreeFetcher         *self,
                                          GPtrArray             *mirrorlist,
                                          const char            *filename,
                                          OstreeFetcherRequestFlags flags,
+                                         const char            *if_none_match,
+                                         guint64                if_modified_since,
                                          guint64                max_size,
                                          int                    priority,
                                          GCancellable          *cancellable,
@@ -132,12 +134,17 @@ void _ostree_fetcher_request_to_tmpfile (OstreeFetcher         *self,
 gboolean _ostree_fetcher_request_to_tmpfile_finish (OstreeFetcher *self,
                                                     GAsyncResult  *result,
                                                     GLnxTmpfile   *out_tmpf,
+                                                    gboolean      *out_not_modified,
+                                                    char         **out_etag,
+                                                    guint64       *out_last_modified,
                                                     GError       **error);
 
 void _ostree_fetcher_request_to_membuf (OstreeFetcher         *self,
                                         GPtrArray             *mirrorlist,
                                         const char            *filename,
                                         OstreeFetcherRequestFlags flags,
+                                        const char            *if_none_match,
+                                        guint64                if_modified_since,
                                         guint64                max_size,
                                         int                    priority,
                                         GCancellable          *cancellable,
@@ -147,6 +154,9 @@ void _ostree_fetcher_request_to_membuf (OstreeFetcher         *self,
 gboolean _ostree_fetcher_request_to_membuf_finish (OstreeFetcher *self,
                                                    GAsyncResult  *result,
                                                    GBytes       **out_buf,
+                                                   gboolean      *out_not_modified,
+                                                   char         **out_etag,
+                                                   guint64       *out_last_modified,
                                                    GError       **error);
 
 
