@@ -68,7 +68,7 @@
  * The volume monitor used to find mounted volumes can be overridden by setting
  * #OstreeRepoFinderMount:monitor. By default, g_volume_monitor_get() is used.
  *
- * Since: 2017.8
+ * Since: 2018.6
  */
 
 typedef GList/*<owned GObject>*/ ObjectList;
@@ -336,7 +336,6 @@ ostree_repo_finder_mount_resolve_async (OstreeRepoFinder                  *finde
       g_autoptr(GHashTable) repo_to_refs = NULL;  /* (element-type UriAndKeyring GHashTable) */
       GHashTable *supported_ref_to_checksum;  /* (element-type OstreeCollectionRef utf8) */
       GHashTableIter iter;
-      UriAndKeyring *repo;
       g_autoptr(GError) local_error = NULL;
 
       mount_name = g_mount_get_name (mount);
@@ -434,7 +433,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       g_array_sort (repos_refs, repo_and_refs_compare);
 
       /* Also check the well-known special-case directories in the mount.
-       * Add them after sorting, so they’re always last. */
+       * Add them after sorting, so they’re always last.
+       * NOTE: If you change these, update the man page. */
       const gchar * const well_known_repos[] =
         {
           ".ostree/repo",
@@ -524,6 +524,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       /* Aggregate the results. */
       g_hash_table_iter_init (&iter, repo_to_refs);
 
+      UriAndKeyring *repo;
       while (g_hash_table_iter_next (&iter, (gpointer *) &repo, (gpointer *) &supported_ref_to_checksum))
         {
           g_autoptr(OstreeRemote) remote = NULL;
@@ -545,7 +546,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
            * the code in ostree_repo_pull_from_remotes_async() will be able to
            * check it just as quickly as we can here; so don’t duplicate the
            * code. */
-          g_ptr_array_add (results, ostree_repo_finder_result_new (remote, finder, priority, supported_ref_to_checksum, 0));
+          g_ptr_array_add (results, ostree_repo_finder_result_new (remote, finder, priority, supported_ref_to_checksum, NULL, 0));
         }
     }
 
@@ -648,7 +649,7 @@ ostree_repo_finder_mount_class_init (OstreeRepoFinderMountClass *klass)
    *
    * Volume monitor to use to look up mounted volumes when queried.
    *
-   * Since: 2017.8
+   * Since: 2018.6
    */
   g_object_class_install_property (object_class, PROP_MONITOR,
                                    g_param_spec_object ("monitor",
@@ -679,7 +680,7 @@ ostree_repo_finder_mount_iface_init (OstreeRepoFinderInterface *iface)
  * be used.
  *
  * Returns: (transfer full): a new #OstreeRepoFinderMount
- * Since: 2017.8
+ * Since: 2018.6
  */
 OstreeRepoFinderMount *
 ostree_repo_finder_mount_new (GVolumeMonitor *monitor)
