@@ -27,6 +27,7 @@
 #include <gio/gio.h>
 #include <glib.h>
 #include <glib-object.h>
+#include <libglnx.h>
 
 #include "ostree-autocleanups.h"
 #include "ostree-core.h"
@@ -132,13 +133,13 @@ static void resolve_cb (GObject      *obj,
  * which the result provides. If the result provides the latest commit for a ref
  * across all of the results, the checksum will be set. Otherwise, if the
  * result provides an outdated commit, or doesn’t provide a given ref at all,
- * the ref will not be set. Results which provide none of the requested @refs
- * may be listed with an empty refs map.
+ * the checksum will not be set. Results which provide none of the requested
+ * @refs may be listed with an empty refs map.
  *
  * Pass the results to ostree_repo_pull_from_remotes_async() to pull the given
  * @refs from those remotes.
  *
- * Since: 2017.8
+ * Since: 2018.6
  */
 void
 ostree_repo_finder_resolve_async (OstreeRepoFinder                  *self,
@@ -196,7 +197,7 @@ resolve_cb (GObject      *obj,
  *
  * Returns: (transfer full) (element-type OstreeRepoFinderResult): array of zero
  *    or more results
- * Since: 2017.8
+ * Since: 2018.6
  */
 GPtrArray *
 ostree_repo_finder_resolve_finish (OstreeRepoFinder  *self,
@@ -254,7 +255,7 @@ static void resolve_all_finished_one (GTask *task);
  * A version of ostree_repo_finder_resolve_async() which queries one or more
  * @finders in parallel and combines the results.
  *
- * Since: 2017.8
+ * Since: 2018.6
  */
 void
 ostree_repo_finder_resolve_all_async (OstreeRepoFinder * const          *finders,
@@ -411,7 +412,7 @@ resolve_all_finished_one (GTask *task)
  *
  * Returns: (transfer full) (element-type OstreeRepoFinderResult): array of zero
  *    or more results
- * Since: 2017.8
+ * Since: 2018.6
  */
 GPtrArray *
 ostree_repo_finder_resolve_all_finish (GAsyncResult  *result,
@@ -436,6 +437,9 @@ G_DEFINE_BOXED_TYPE (OstreeRepoFinderResult, ostree_repo_finder_result,
  *    priority
  * @ref_to_checksum: (element-type OstreeCollectionRef utf8) (transfer none):
  *    map of collection–ref pairs to checksums provided by this result
+ * @ref_to_timestamp: (element-type OstreeCollectionRef guint64) (nullable)
+ *    (transfer none): map of collection–ref pairs to timestamps provided by this
+ *    result
  * @summary_last_modified: Unix timestamp (seconds since the epoch, UTC) when
  *    the summary file for the result was last modified, or `0` if this is unknown
  *
@@ -443,13 +447,14 @@ G_DEFINE_BOXED_TYPE (OstreeRepoFinderResult, ostree_repo_finder_result,
  * are as described in the #OstreeRepoFinderResult documentation.
  *
  * Returns: (transfer full): a new #OstreeRepoFinderResult
- * Since: 2017.8
+ * Since: 2018.6
  */
 OstreeRepoFinderResult *
 ostree_repo_finder_result_new (OstreeRemote     *remote,
                                OstreeRepoFinder *finder,
                                gint              priority,
                                GHashTable       *ref_to_checksum,
+                               GHashTable       *ref_to_timestamp,
                                guint64           summary_last_modified)
 {
   g_autoptr(OstreeRepoFinderResult) result = NULL;
@@ -463,6 +468,7 @@ ostree_repo_finder_result_new (OstreeRemote     *remote,
   result->finder = g_object_ref (finder);
   result->priority = priority;
   result->ref_to_checksum = g_hash_table_ref (ref_to_checksum);
+  result->ref_to_timestamp = ref_to_timestamp != NULL ? g_hash_table_ref (ref_to_timestamp) : NULL;
   result->summary_last_modified = summary_last_modified;
 
   return g_steal_pointer (&result);
@@ -475,7 +481,7 @@ ostree_repo_finder_result_new (OstreeRemote     *remote,
  * Copy an #OstreeRepoFinderResult.
  *
  * Returns: (transfer full): a newly allocated copy of @result
- * Since: 2017.8
+ * Since: 2018.6
  */
 OstreeRepoFinderResult *
 ostree_repo_finder_result_dup (OstreeRepoFinderResult *result)
@@ -484,7 +490,7 @@ ostree_repo_finder_result_dup (OstreeRepoFinderResult *result)
 
   return ostree_repo_finder_result_new (result->remote, result->finder,
                                         result->priority, result->ref_to_checksum,
-                                        result->summary_last_modified);
+                                        result->ref_to_timestamp, result->summary_last_modified);
 }
 
 /**
@@ -497,7 +503,7 @@ ostree_repo_finder_result_dup (OstreeRepoFinderResult *result)
  *
  * Returns: <0 if @a is ordered before @b, 0 if they are ordered equally,
  *    >0 if @b is ordered before @a
- * Since: 2017.8
+ * Since: 2018.6
  */
 gint
 ostree_repo_finder_result_compare (const OstreeRepoFinderResult *a,
@@ -544,7 +550,7 @@ ostree_repo_finder_result_compare (const OstreeRepoFinderResult *a,
  *
  * Free the given @result.
  *
- * Since: 2017.8
+ * Since: 2018.6
  */
 void
 ostree_repo_finder_result_free (OstreeRepoFinderResult *result)
@@ -554,6 +560,7 @@ ostree_repo_finder_result_free (OstreeRepoFinderResult *result)
   /* This may be NULL iff the result is freed half-way through find_remotes_cb()
    * in ostree-repo-pull.c, and at no other time. */
   g_clear_pointer (&result->ref_to_checksum, g_hash_table_unref);
+  g_clear_pointer (&result->ref_to_timestamp, g_hash_table_unref);
   g_object_unref (result->finder);
   ostree_remote_unref (result->remote);
   g_free (result);
@@ -565,7 +572,7 @@ ostree_repo_finder_result_free (OstreeRepoFinderResult *result)
  *
  * Free the given @results array, freeing each element and the container.
  *
- * Since: 2017.8
+ * Since: 2018.6
  */
 void
 ostree_repo_finder_result_freev (OstreeRepoFinderResult **results)
