@@ -1,7 +1,8 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
- *
+/*
  * Copyright (C) 2015 Colin Walters <walters@verbum.org>
  *
+ * SPDX-License-Identifier: LGPL-2.0+
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -33,5 +34,10 @@ ot_parse_keyvalue (const char  *keyvalue,
                    char       **out_key,
                    char       **out_value,
                    GError     **error);
+gboolean
+ot_ptr_array_find_with_equal_func (GPtrArray     *haystack,
+                                   gconstpointer  needle,
+                                   GEqualFunc     equal_func,
+                                   guint         *index_);
 
 G_END_DECLS
