@@ -1,6 +1,8 @@
 /*
  * Copyright (C) 2016 Colin Walters <walters@verbum.org>
  *
+ * SPDX-License-Identifier: LGPL-2.0+
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -25,7 +27,7 @@
 #include "otutil.h"
 
 gboolean
-ostree_builtin_trivial_httpd (int argc, char **argv, GCancellable *cancellable, GError **error)
+ostree_builtin_trivial_httpd (int argc, char **argv, OstreeCommandInvocation *invocation, GCancellable *cancellable, GError **error)
 {
   g_autoptr(GPtrArray) new_argv = g_ptr_array_new ();
 
